==> zio-aws-docdb_2.13-5.17.146.2-sources.jar: zio/aws/docdb/model/DescribeGlobalClustersResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeGlobalClustersResponse(
    marker: Option[String] = None,
    globalClusters: Option[Iterable[zio.aws.docdb.model.GlobalCluster]] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribeGlobalClustersResponse = {
    import DescribeGlobalClustersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribeGlobalClustersResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        globalClusters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.globalClusters)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.DescribeGlobalClustersResponse.ReadOnly =
    zio.aws.docdb.model.DescribeGlobalClustersResponse.wrap(buildAwsValue())
}
object DescribeGlobalClustersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribeGlobalClustersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.DescribeGlobalClustersResponse =
      zio.aws.docdb.model.DescribeGlobalClustersResponse(
        marker.map(value => value),
        globalClusters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: Option[String]
    def globalClusters: Option[List[zio.aws.docdb.model.GlobalCluster.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getGlobalClusters
        : ZIO[Any, AwsError, List[zio.aws.docdb.model.GlobalCluster.ReadOnly]] =
      AwsError.unwrapOptionField("globalClusters", globalClusters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribeGlobalClustersResponse
  ) extends zio.aws.docdb.model.DescribeGlobalClustersResponse.ReadOnly {
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
    override val globalClusters
        : Option[List[zio.aws.docdb.model.GlobalCluster.ReadOnly]] = scala
      .Option(impl.globalClusters())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.docdb.model.GlobalCluster.wrap(item)
        }.toList
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribeGlobalClustersResponse
  ): zio.aws.docdb.model.DescribeGlobalClustersResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-docdb_2.13-5.17.295.14-sources.jar: zio/aws/docdb/model/DescribeGlobalClustersResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeGlobalClustersResponse(
    marker: Optional[String] = Optional.Absent,
    globalClusters: Optional[Iterable[zio.aws.docdb.model.GlobalCluster]] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribeGlobalClustersResponse = {
    import DescribeGlobalClustersResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribeGlobalClustersResponse
      .builder()
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .optionallyWith(
        globalClusters.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.globalClusters)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.DescribeGlobalClustersResponse.ReadOnly =
    zio.aws.docdb.model.DescribeGlobalClustersResponse.wrap(buildAwsValue())
}
object DescribeGlobalClustersResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribeGlobalClustersResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.DescribeGlobalClustersResponse =
      zio.aws.docdb.model.DescribeGlobalClustersResponse(
        marker.map(value => value),
        globalClusters.map(value =>
          value.map { item =>
            item.asEditable
          }
        )
      )
    def marker: Optional[String]
    def globalClusters
        : Optional[List[zio.aws.docdb.model.GlobalCluster.ReadOnly]]
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
    def getGlobalClusters
        : ZIO[Any, AwsError, List[zio.aws.docdb.model.GlobalCluster.ReadOnly]] =
      AwsError.unwrapOptionField("globalClusters", globalClusters)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribeGlobalClustersResponse
  ) extends zio.aws.docdb.model.DescribeGlobalClustersResponse.ReadOnly {
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
    override val globalClusters
        : Optional[List[zio.aws.docdb.model.GlobalCluster.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.globalClusters())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.docdb.model.GlobalCluster.wrap(item)
          }.toList
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribeGlobalClustersResponse
  ): zio.aws.docdb.model.DescribeGlobalClustersResponse.ReadOnly = new Wrapper(
    impl
  )
}
